ReadyAnd

Type Alias ReadyAnd 

pub type ReadyAnd<'a, T, Request> = Ready<'a, T, Request>;
๐Ÿ‘ŽDeprecated since 0.4.6:

Please use the Ready future instead

A future that yields a mutable reference to the service when it is ready to accept a request.

ReadyAnd values are produced by ServiceExt::ready_and.

Aliased Type

pub struct ReadyAnd<'a, T, Request>(/* private fields */);